Philippine Classification of Individual Consumption According to Purpose (PCOICOP)
Source:R/pcoicop.R
get_pcoicop.RdPhilippine Classification of Individual Consumption According to Purpose (PCOICOP)
Arguments
- version
Character. Version of the PCOICOP dataset. Default is the latest available (
"2020"). Use"2009"for the 2009 edition.- level
Character. Classification level:
"all","divisions","groups","class","sub-class","item", or"subitem"(default).- minimal
Logical. If
TRUE(default), returns onlyvalueandlabelcolumns.- cols
Optional character vector of additional columns to include (
"description"is the only extra column available).