Learn R Programming

phscs (version 0.1.0)

get_pcpc: Philippine Central Product Classification (PCPC)

Description

Philippine Central Product Classification (PCPC)

Usage

get_pcpc(
  ...,
  token = NULL,
  version = NULL,
  level = NULL,
  harmonize = TRUE,
  minimal = TRUE,
  cols = NULL
)

Value

A tibble containing the requested PCPC data.

Arguments

...

See ?dplyr::filter. Expressions that return a logical value, and are defined in terms of the variables in returned data. If multiple expressions are included, they are combined with the & operator. Only rows for which all conditions evaluate to TRUE are kept.

token

Character. API access token.

version

Character. Version of the PCPC to retrieve. Default is NULL. If NULL, the latest version is used.

level

Character. Level of detail to retrieve. Options are "all", "sections", "divisions", "groups", "classes", "sub-classes", and "item".

harmonize

Logical. If TRUE, formats and standardizes the returned data. Default is TRUE.

minimal

Logical. If TRUE, returns a simplified dataset. Default is TRUE.

cols

Optional. Character vector of additional columns to include when minimal = FALSE.

References

https://psa.gov.ph/classification/pcpc

Examples

Run this code
if (FALSE) {
get_pcpc(token = "your_api_token")
}

# If token is not provided, the function will fetch from local cache or
# download the latest version from remote repo
pcpc <- get_pcpc()

# Get specific level
pcpc_filtered <- get_pcpc(level = "sections")
pcpc_filtered

Run the code above in your browser using DataLab