- ...
See ?dplyr::filter. Expressions that return a logical value, and are defined in terms of the variables in returned data. If multiple expressions are included, they are combined with the & operator. Only rows for which all conditions evaluate to TRUE are kept.
- token
Character. API access token. If NULL, retrieves data from the local cache.
- version
Character. PSGC version such as: "Q3_2025", "July_2025", "Q2_2025", "Q1_2025", "April_2024", "Q4_2024", "Q3_2024", "Q2_2024", and "Q4_2023", "Q2_2021". If NULL, retrieves the latest version available in the local cache.
- level
Character. Level of geographic data to retrieve. Available options are: "all", "regions", "provinces", "hucs" "municipalities", "sub_municipalities" "barangays", "income_classification", "urban_rural", and "city_class".
- harmonize
Logical. If TRUE, formats and standardizes the returned data. Default is TRUE.
- minimal
Logical. If TRUE, returns a simplified dataset. Default is TRUE.
- cols
Optional. Character vector of additional columns to include when minimal = FALSE.